# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from visier_api_data_in.models.assign_connector_credentials_response_dto import AssignConnectorCredentialsResponseDTO

class TestAssignConnectorCredentialsResponseDTO(unittest.TestCase):
    """AssignConnectorCredentialsResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AssignConnectorCredentialsResponseDTO:
        """Test AssignConnectorCredentialsResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AssignConnectorCredentialsResponseDTO`
        """
        model = AssignConnectorCredentialsResponseDTO()
        if include_optional:
            return AssignConnectorCredentialsResponseDTO(
                tenants = [
                    visier_api_data_in.models.assign_connector_credentials_by_tenant_response_dto.AssignConnectorCredentialsByTenantResponseDTO(
                        connectors = [
                            visier_api_data_in.models.assign_connector_with_credentials_response_dto.AssignConnectorWithCredentialsResponseDTO(
                                connector = null, 
                                credential = null, )
                            ], 
                        message = '', 
                        status = 'Unknown', 
                        tenant_code = '', )
                    ]
            )
        else:
            return AssignConnectorCredentialsResponseDTO(
        )
        """

    def testAssignConnectorCredentialsResponseDTO(self):
        """Test AssignConnectorCredentialsResponseDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
